package com.bweb.controller.item;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.security.UserCenter;
import com.hfkj.common.utils.ResponseMsgUtil;
import com.hfkj.entity.EnItem;
import com.hfkj.model.ResponseData;
import com.hfkj.model.SecUserSessionObject;
import com.hfkj.service.item.EnItemService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

@Controller
@RequestMapping(value="/enItem")
@Api(value="项目管理")
public class EnItemController {

    Logger log = LoggerFactory.getLogger(EnItemController.class);
    @Resource
    private UserCenter userCenter;
    @Resource
    private EnItemService enItemService;


    @RequestMapping(value="/create",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "创建项目")
    public ResponseData create(@RequestBody EnItem body) {
        try {
            if (body == null
                    || StringUtils.isBlank(body.getContactInfo())
                    || StringUtils.isBlank(body.getProjectAddress())
                    || StringUtils.isBlank(body.getProjectLeader())
                    || StringUtils.isBlank(body.getProjectName())
            ) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);
            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }

            body.setUpdateTime(new Date());
            body.setCreateTime(new Date());
            body.setCreateUser(sessionModel.getAccount().getId());
            body.setStatus(2);
            body.setCreateUserName(sessionModel.getAccount().getUserName());
            enItemService.create(body);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/update",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "修改项目")
    public ResponseData update(@RequestBody EnItem body) {
        try {
            if (body == null
                    || body.getId() == null
                    || StringUtils.isBlank(body.getContactInfo())
                    || StringUtils.isBlank(body.getProjectAddress())
                    || StringUtils.isBlank(body.getProjectLeader())
                    || StringUtils.isBlank(body.getProjectName())
            ) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);
            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }

            Map<String , Object > map = new HashMap<>();

            map.put("id",body.getId());
            map.put("createUser" , sessionModel.getAccount().getId());

            EnItem enItem = enItemService.queryDetailByMap(map);
            if (enItem == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "项目不存在");
            }

            enItem.setContactInfo(body.getContactInfo());
            enItem.setProjectAddress(body.getProjectAddress());
            enItem.setProjectLeader(body.getProjectLeader());
            enItem.setProjectName(body.getProjectName());
            enItem.setUpdateTime(new Date());
            enItem.setUpdateUser(sessionModel.getAccount().getId());
            enItem.setUpdateUserName(sessionModel.getAccount().getUserName());
            enItemService.update(enItem);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/updateStatus",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "修改状态")
    public ResponseData updateStatus(@RequestBody EnItem body) {
        try {
            if (body == null
                    || body.getId() == null
                    || body.getStatus() == null
            ) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);
            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }

            Map<String , Object > map = new HashMap<>();

            map.put("id",body.getId());
            map.put("createUser" , sessionModel.getAccount().getId());

            EnItem enItem = enItemService.queryDetailByMap(map);
            if (enItem == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "项目不存在");
            }

            enItem.setStatus(body.getStatus());
            enItem.setUpdateTime(new Date());
            enItem.setUpdateUser(sessionModel.getAccount().getId());
            enItem.setUpdateUserName(sessionModel.getAccount().getUserName());
            enItemService.update(enItem);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/deleteItem",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "删除")
    public ResponseData deleteGoods(@RequestParam(value = "id" , required = false) Long id) {
        try {

            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);
            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }

            Map<String , Object > map = new HashMap<>();

            map.put("id",id);
            map.put("createUser" , sessionModel.getAccount().getId());

            EnItem enItem = enItemService.queryDetailByMap(map);
            if (enItem == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "项目不存在");
            }

            enItemService.delete(id , false);

            return ResponseMsgUtil.success("删除成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }



    @RequestMapping(value="/queryDetail",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询详情")
    public ResponseData queryDetail(@RequestParam(value = "id" , required = false) Long id) {
        try {

            return ResponseMsgUtil.success(enItemService.queryDetail(id));

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/queryList",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询项目列表")
    public ResponseData queryList(@RequestParam(value = "contactInfo" , required = false) String contactInfo,
                                  @RequestParam(value = "projectAddress" , required = false) String projectAddress,
                                  @RequestParam(value = "status" , required = false) Integer status,
                                  @RequestParam(value = "projectLeader" , required = false) String projectLeader,
                                  @RequestParam(value = "projectName" , required = false) String projectName,
                                  @RequestParam(value = "pageNum" , required = true) Integer pageNum,
                                  @RequestParam(value = "pageSize" , required = true) Integer pageSize) {
        try {
            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);
            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }

            Map<String,Object> param = new HashMap<>();
            param.put("contactInfo", contactInfo);
            param.put("projectAddress", projectAddress);
            param.put("projectLeader", projectLeader);
            param.put("projectName", projectName);
            param.put("status", status);
            param.put("createUser", sessionModel.getAccount().getId());

            PageHelper.startPage(pageNum, pageSize);
            return ResponseMsgUtil.success(new PageInfo<>(enItemService.getList(param)));

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

}
